@@ -76,7 +76,8 @@ class OOPSObserver:
         if ids:
             event['isError'] = False
             event.pop('failure', None)
-            event['message'] = "Logged OOPS id %s: %s: %s" % (
-                report['id'], report['type'], report['value']) 
+            event['message'] = ["Logged OOPS id %s: %s: %s" % (
+                report['id'], report.get('type', 'No exception type'),
+                report.get('value', 'No exception value'))]
         if ids is not None:
             self.fallback(event)
